summaryrefslogtreecommitdiffstats
path: root/block/blk-wbt.h
diff options
context:
space:
mode:
Diffstat (limited to 'block/blk-wbt.h')
-rw-r--r--block/blk-wbt.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/block/blk-wbt.h b/block/blk-wbt.h
index 8038b4a0d4efc..d6a125e49db57 100644
--- a/block/blk-wbt.h
+++ b/block/blk-wbt.h
@@ -14,13 +14,15 @@ enum wbt_flags {
WBT_TRACKED = 1, /* write, tracked for throttling */
WBT_READ = 2, /* read */
WBT_KSWAPD = 4, /* write, from kswapd */
+ WBT_DISCARD = 8, /* discard */
- WBT_NR_BITS = 3, /* number of bits */
+ WBT_NR_BITS = 4, /* number of bits */
};
enum {
WBT_RWQ_BG = 0,
WBT_RWQ_KSWAPD,
+ WBT_RWQ_DISCARD,
WBT_NUM_RWQ,
};